@@ -22,7 +22,7 @@
 # The Script was developed for the operating systems Solaris, Linux and MacOS.
 
 # The SDK name
-OO_SDK_NAME=libreoffice5.1_sdk
+OO_SDK_NAME=libreoffice6.1_sdk
 export OO_SDK_NAME
 
 # Installation directory of the Software Development Kit.
@@ -52,7 +52,7 @@ OO_SDK_SED_HOME=/usr/bin
 
 # Directory of the C++ compiler.
 # Example: OO_SDK_CPP_HOME=/usr/bin
-OO_SDK_CPP_HOME=/usr/bin
+OO_SDK_CPP_HOME=/usr/lib/distcc/bin
 
 # Directory of the Java SDK.
 # Example: OO_SDK_JAVA_HOME=/usr/jdk/jdk1.6.0_10
@@ -81,12 +81,10 @@ sdk_platform=`/bin/sh ${OO_SDK_HOME}/config.guess | cut -d"-" -f3,4`
 
 # Set the directory name.
 programdir=program
-javadir=bin
 sdk_lo_java_dir=program/classes
 case ${sdk_platform} in
   darwin*)
     programdir="Contents/MacOS"
-    javadir=Commands
     sdk_lo_java_dir=Contents/Resources/java
     ;;
 esac
@@ -244,7 +242,7 @@ fi
 # Add directory of the Java tools to the path, if necessary.
 if [ -n "${OO_SDK_JAVA_HOME}" ]
 then
-    PATH=${OO_SDK_JAVA_HOME}/${javadir}:${PATH}
+    PATH=${OO_SDK_JAVA_HOME}/bin:${PATH}
 #    JAVA_HOME=${OO_SDK_JAVA_HOME}
 #    export JAVA_HOME
     export OO_SDK_JAVA_HOME
@@ -300,5 +298,3 @@ echo " * SDK Output directory = $OO_SDK_OUT"
 echo " * Auto deployment = $SDK_AUTO_DEPLOYMENT"
 echo " *"
 echo " ************************************************************************"
-
-echo "]2;Shell prepared with the LibreOffice SDK environment"
